@@ -11,11 +11,12 @@ fi
 TMPDIR=$ORBIT_TMPDIR;
 export TMPDIR;
 
-export BONOBO_ACTIVATION_SERVER='../../activation-server/bonobo-activation-server';
-export BONOBO_ACTIVATION_DEBUG_OUTPUT='1';
-export BONOBO_ACTIVATION_PATH=".:$BONOBO_ACTIVATION_PATH";
-export PATH=".:$PATH";
-export LD_LIBRARY_PATH="./.libs:$LD_LIBRARY_PATH";
+BONOBO_ACTIVATION_SERVER="../../activation-server/bonobo-activation-server";
+BONOBO_ACTIVATION_DEBUG_OUTPUT="1";
+PATH=".:$PATH";
+LD_LIBRARY_PATH="./.libs:$LD_LIBRARY_PATH";
+
+export BONOBO_ACTIVATION_SERVER BONOBO_ACTIVATION_DEBUG_OUTPUT BONOBO_ACTIVATION_PATH PATH LD_LIBRARY_PATH
 
 if ./bonobo-activation-test; then
     exit 0;
